Reprocess — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# Reprocess

## Introduction

Ce programme recrée les données récapitulatives horaires, quotidiennes et mensuelles qui sont créées par le programme Process.py. Il doit être exécuté chaque fois que vous mettez à jour vers une nouvelle version de pywws.

Le programme est très simple à utiliser:

    python -m pywws.Reprocess data_directory

Où `data_directory` est le répertoire ou sont stockées vos données.

## API détaillé

Regenerate hourly and daily summary data

    usage: python -m pywws.Reprocess [options] data_dir
    options are:
     -h | --help     display this help
     -v | --verbose  increase number of informative messages
    data_dir is the root directory of the weather data

Fonctions

`Reprocess`(data_dir) |
`main`([argv]) |

`pywws.Reprocess.` `Reprocess`(data_dir)

`pywws.Reprocess.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »